@@ -597,7 +597,7 @@ bins_to_breaks = function(bins, dt, to_string=FALSE, save_name=NULL) {
 #' @param no_cores Number of CPU cores for parallel computation. Defaults NULL. If no_cores is NULL, the no_cores will set as 1 if length of x variables less than 10, and will set as the number of all CPU cores if the length of x variables greater than or equal to 10.
 #' @param print_step A non-negative integer. Default is 1. If print_step>0, print variable names by each print_step-th iteration. If print_step=0 or no_cores>1, no message is print.
 #' @param method Optimal binning method, it should be "tree" or "chimerge". Default is "tree".
-#' @param save_breaks_list Logical, whether to save breaks_list in current working directory. Default is FALSE.
+#' @param save_breaks_list A string. The file name to save breaks_list. Default is None.
 #' @param ignore_const_cols Logical. Ignore constant columns. Default is TRUE.
 #' @param ignore_datetime_cols Logical. Ignore datetime columns. Default is TRUE.
 #' @param check_cate_num Logical. Check categorical columns if have more than 50 unique values. Default is TRUE.
@@ -670,7 +670,7 @@ woebin = function(dt, y, x=NULL, breaks_list=NULL, special_values=NULL, stop_lim
 
   # global variable
   i = NULL
-  # arguments
+  # arguments ------
   # print_info
   print_info = list(...)[['print_info']]
   if (is.null(print_info)) print_info = TRUE
@@ -751,13 +751,12 @@ woebin = function(dt, y, x=NULL, breaks_list=NULL, special_values=NULL, stop_lim
     method = "tree"
   }
 
-  # binning for each x variable
+  # binning ------
   # loop on xs # https://www.r-bloggers.com/how-to-go-parallel-in-r-basics-tips/
   if (is.null(no_cores) || no_cores<1) {
     no_cores = ifelse(xs_len < 10, 1, detectCores(logical=F))
   }
 
-
   bins = list()
   if (no_cores == 1) {
     for (i in 1:xs_len) {
@@ -783,7 +782,7 @@ woebin = function(dt, y, x=NULL, breaks_list=NULL, special_values=NULL, stop_lim
     # run
     bins <-
       foreach(
-        i = 1:xs_len,
+        i = seq_len(xs_len),
         .combine = list,
         .multicombine = TRUE,
         .maxcombine = xs_len+1,
@@ -793,7 +792,7 @@ woebin = function(dt, y, x=NULL, breaks_list=NULL, special_values=NULL, stop_lim
           if (xs_len==1) bs = list(bs)
           setNames(bs, xs)
         },
-        .export = c("dt", "xs", "y", "breaks_list", "init_count_distr", "stop_limit", "bin_num_limit")
+        .export = c('dt', 'xs', 'y', 'breaks_list', 'special_values', 'init_count_distr', 'count_distr_limit', 'stop_limit', 'bin_num_limit', 'method')
       ) %dopar% {
         x_i = xs[i]
 
@@ -804,7 +803,8 @@ woebin = function(dt, y, x=NULL, breaks_list=NULL, special_values=NULL, stop_lim
           spl_val=special_values[[x_i]],
           init_count_distr=init_count_distr,
           count_distr_limit=count_distr_limit,
-          stop_limit=stop_limit, bin_num_limit=bin_num_limit,
+          stop_limit=stop_limit,
+          bin_num_limit=bin_num_limit,
           method=method
         )), silent = TRUE)
       }
@@ -814,7 +814,7 @@ woebin = function(dt, y, x=NULL, breaks_list=NULL, special_values=NULL, stop_lim
   # running time
   rs = proc.time() - start_time
   # hms
-  if (rs[3] > 10) cat(sprintf("Binning on %s rows and %s columns in %s",nrow(dt),ncol(dt),sec_to_hms(rs[3])),"\n")
+  if (rs[3] > 10 & print_info) cat(sprintf("[INFO] Binning on %s rows and %s columns in %s",nrow(dt),ncol(dt),sec_to_hms(rs[3])),"\n")
   # save breaks_list
   if (!is.null(save_breaks_list)) bins_to_breaks(bins, dt, to_string=TRUE, save_name=save_breaks_list)
   return(bins)
@@ -975,14 +975,14 @@ woebin_ply = function(dt, bins, no_cores=NULL, print_step=0L, replace_blank_na=T
         .init = dt_init,
         .inorder = FALSE,
         .errorhandling = "pass",
-        .export = c("dt", "xs")
+        .export = c('dt', 'bins', 'xs')
       ) %dopar% {
         x_i = xs[i]
 
         binx = bins[variable==x_i]
         dtx = dt[, x_i, with=FALSE]
 
-        woepoints_ply1(dtx, binx, x_i, woe_points="woe")
+        woepoints_ply1(dtx, binx, x_i, woe_points='woe')
       }
     # finish
     stopImplicitCluster()
@@ -991,7 +991,7 @@ woebin_ply = function(dt, bins, no_cores=NULL, print_step=0L, replace_blank_na=T
   # running time
   rs = proc.time() - start_time
   # hms
-  if (rs[3] > 10) cat(sprintf("Woe transformating on %s rows and %s columns in %s",nrow(dt),xs_len,sec_to_hms(rs[3])),"\n")
+  if (rs[3] > 10 & print_info) cat(sprintf("[INFO] Woe transformating on %s rows and %s columns in %s",nrow(dt),xs_len,sec_to_hms(rs[3])),"\n")
 
   return(dat)
 }
@@ -1199,7 +1199,7 @@ woebin_adj_break_plot = function(dt, y, x_i, breaks, stop_limit, sv_i, method) {
 #' @param adj_all_var Logical, whether to show variables with monotonic woe trends. Default is FALSE.
 #' @param special_values The values specified in special_values will in separate bins. Default is NULL.
 #' @param method Optimal binning method, it should be "tree" or "chimerge". Default is "tree".
-#' @param save_breaks_list Logical, whether to save breaks_list in current working directory. Default is FALSE.
+#' @param save_breaks_list A string. The file name to save breaks_list. Default is None.
 #'
 #' @return A list of modified break points of each x variables.
 #'
